@@ -1,8 +1,8 @@
 import os
 import sys
-from robot.variables import GLOBAL_VARIABLES
 from robot.api import logger
 from keywordgroup import KeywordGroup
+from robot.libraries.BuiltIn import BuiltIn
 
 class _LoggingKeywords(KeywordGroup):
 
@@ -12,10 +12,12 @@ class _LoggingKeywords(KeywordGroup):
         logger.debug(message)
 
     def _get_log_dir(self):
-        logfile = GLOBAL_VARIABLES['${LOG FILE}']
+        variables = BuiltIn().get_variables()
+
+        logfile = variables['${LOG FILE}']
         if logfile != 'NONE':
             return os.path.dirname(logfile)
-        return GLOBAL_VARIABLES['${OUTPUTDIR}']
+        return variables['${OUTPUTDIR}']
 
     def _html(self, message):
         logger.info(message, True, False)
@@ -38,4 +40,4 @@ class _LoggingKeywords(KeywordGroup):
         return items
 
     def _warn(self, message):
-        logger.warn(message)
\ No newline at end of file
+        logger.warn(message)
